Skip to contents

Creates a single-row tibble with specified compartment information, using the standardised structure from eDataDRF::initialise_campaign_tibble(). Function will return an error if compartment, sub_compartment, or category are not of the correct variable type, but it doesn't check for vocabulary

Usage

create_compartment_combination(compartment, sub_compartment, category)

Arguments

compartment

Character string specifying the environmental compartment (eDataDRF::environ_compartments_vocabulary())

sub_compartment

Character string specifying the sub-compartment (eDataDRF::environ_compartments_sub_vocabulary())

category

Character string specifying the measured category (eDataDRF::measured_categories_vocabulary())

Value

tibble with one row containing the specified compartment information

Examples

create_compartment_combination("Aquatic", "Surface water", "External")
#> # A tibble: 1 × 3
#>   ENVIRON_COMPARTMENT ENVIRON_COMPARTMENT_SUB MEASURED_CATEGORY
#>   <chr>               <chr>                   <chr>            
#> 1 Aquatic             Surface water           External         
create_compartment_combination("Biota", "Biota, Aquatic", "Internal")
#> # A tibble: 1 × 3
#>   ENVIRON_COMPARTMENT ENVIRON_COMPARTMENT_SUB MEASURED_CATEGORY
#>   <chr>               <chr>                   <chr>            
#> 1 Biota               Biota, Aquatic          Internal