CREED Relevance Criteria Configuration
Source:R/mod_CREED_fct_helpers.R
CREED_relevance_criteria_config.RdReturns the configuration list for all 11 CREED relevance criteria (RV1-RV11). Each criterion includes its title and whether it is Required or Recommended.
Value
A named list where each element is a criterion configuration with:
- title
Character. Human-readable criterion title.
- type
Character. Either "Required" or "Recommended".
Details
Relevance criteria assess the fitness-for-purpose of the data:
RV1-RV2: Media (sample medium, collection method)
RV3-RV4: Spatial (study area, site type)
RV5-RV7: Temporal (timespan, frequency, conditions)
RV8-RV9: Analytical (analyte, sensitivity)
RV10: Data handling (summary statistics)
RV11: Supporting parameters
Examples
config <- CREED_relevance_criteria_config()
names(config)
#> [1] "RV1" "RV2" "RV3" "RV4" "RV5" "RV6" "RV7" "RV8" "RV9" "RV10"
#> [11] "RV11"
config$RV1
#> $title
#> [1] "Sample Medium/Matrix"
#>
#> $type
#> [1] "Required"
#>