Create a collapsible single-panel accordion containing a markdown file
Source:R/utils_utilities.R
info_accordion.RdCreates a collapsible single-panel bslib accordion displaying the contents of a markdown file, with an info icon.
R/utils_utilities.R
info_accordion.RdCreates a collapsible single-panel bslib accordion displaying the contents of a markdown file, with an info icon.